#include <stdio.h>
#include <mu/options.h>

/* Callbacks to print a message when we find an option. */

int print_example(void *data, char *err) {
  puts("Option found: example");
  return 0;
}

int print_another(void *data, char *err) {
  puts("Option found: another");
  return 0;
}

int main(int argc, char **argv) {
  MU_OPT options[] = {
    {
     .short_opt     = 'e',
     .long_opt      = "example",
     .has_arg       = MU_OPT_NONE,
     .callback_none = print_example
    },
    {
     .short_opt     = 'a',
     .long_opt      = "another",
     .has_arg       = MU_OPT_NONE,
     .callback_none = print_another
    },
    { 0 }       /* So `mu_parse_opts' knows where to stop */
  };

  while (argc > 1) {
    int ret;
    static int stop_parsing = 0;

    /* Parse options. */
    ret = mu_parse_opts(argc, argv, options,
                        MU_OPT_CONTINUE, &stop_parsing);
    if (MU_OPT_ERR(ret))
      return 1;

    /* Shift the arguments (to get rid of the options we just
       parsed). */
    MU_SHIFT_ARGS(ret);

    if (argc > 1) {
      /* Print an argument (we don't have to print them all at once
         because if `mu_parse_opts' doesn't find any options, it will
         just return 0). */
      printf("Argument found: %s\n", argv[1]);
      /* Shift away this argument. */
      MU_SHIFT_ARGS(1);
    }
  }

  /* We need to call this since we passed the MU_OPT_CONTINUE flag to
     `mu_parse_opts'. */
  mu_free_opts(options);

  return 0;
}
